@@ -22,7 +22,7 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.3"
+  __version__ = "0.2.4"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
@@ -130,9 +130,10 @@ class mNotes(object):
       if pixbuf == None:
         pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 600, 400)
       try:
-        self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
+#        self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
         self.pixmap,_ = pixbuf.render_pixmap_and_mask()
-        self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
+#        self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
+        self._drawview.queue_draw()
         del pixbuf
         self._current_note.draw_loaded = True
       except StandardError,e:
@@ -143,9 +144,10 @@ class mNotes(object):
       self._current_note.draw_loaded = False
       pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 600, 400)
       try:
-        self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
+        #self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
         self.pixmap,_ = pixbuf.render_pixmap_and_mask()
         self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
+        self._drawview.set_size_request(-1,-1)
         del pixbuf
         self._current_note.draw_loaded = True
       except StandardError,e:
@@ -163,7 +165,7 @@ class mNotes(object):
       if (self._drawview.window != None) and (self._current_note.draw_loaded == True):
         width, height =600,400 #self._drawview.window.get_size ()
         pixbuf = gtk.gdk.Pixbuf (gtk.gdk.COLORSPACE_RGB, 0, 8, width, height)
-        pixbuf.get_from_drawable(self._drawview.window, self._drawview.window.get_colormap (),0, 0, 0, 0, width, height)
+        pixbuf.get_from_drawable(self.pixmap, self.pixmap.get_colormap (),0, 0, 0, 0, width, height)
         pixbuf.save (self._current_note.get_draw_path(), "jpeg")
         del pixbuf 
         
